% Calculate median and maximum absolute errors
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%   Thermodynamically Consistent Bayesian Analysis    %%%%%%%%%%%
%%%%%%%%%%%       of Closed Biochemical Reaction Systems        %%%%%%%%%%%
%%%%%%%%%%%            Posterior Mode Rate Estimation           %%%%%%%%%%%
%%%%%%%%%%%         Authors: Jenkinson, Zhong, Goutsias         %%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 11/04/2010              %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

function [medAE,maxAE] = trajerr(x0,x0p,pert,kappa,kappaest,tol_high,timings)

%
% Calculate error in the unperturbed system
%

[t,xtrue] = oden13(kappa,x0,[tol_high,tol_high],timings);
[t,xest]  = oden13(kappaest,x0,[tol_high,tol_high],timings);

ratio(1,:) = sum(abs(xest-xtrue),1)./sum(xtrue,1);

%
% Calculate error in the perturbed systems
%

m = 1;

for iter = 1:length(pert)
    if pert(iter) == 1
        m = m+1;
        [t,xtrue]  = oden13(kappa,x0p(:,iter),[tol_high,tol_high],timings);
        [t,xest]   = oden13(kappaest,x0p(:,iter),[tol_high,tol_high],timings);
        ratio(m,:) = sum(abs(xest-xtrue),1)./sum(xtrue,1);
    end   
end

medAE = median(median(ratio));
maxAE = max(max(ratio));