% Write estimation results
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%   Thermodynamically Consistent Bayesian Analysis    %%%%%%%%%%%
%%%%%%%%%%%       of Closed Biochemical Reaction Systems        %%%%%%%%%%%
%%%%%%%%%%%            Posterior Mode Rate Estimation           %%%%%%%%%%%
%%%%%%%%%%%         Authors: Jenkinson, Zhong, Goutsias         %%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 11/04/2010              %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Write posterior mean results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

fid = fopen(['../results/' FolderName '/reports/mean.txt'],'w');
fprintf(fid,'POSTERIOR MEAN ESTIMATION RESULTS\n');
fprintf(fid,'---------------------------------\n');
fprintf(fid,'Distribution of measurement noise: ');
if noiseType == 1
    fprintf(fid,'i.i.d. Gaussian');
elseif noiseType == 2
    fprintf(fid,'correlated Gaussian');
else
    fprintf(fid,'i.i.d. Uniform');
end
fprintf(fid,'\nStandard deviation of measurement errors = %4.4f',sigma);
fprintf(fid,'\nObservation time = %1.2f (min)',time);
fprintf(fid,'\nNumber of measurement points = %1.0f',Q);
fprintf(fid,'\nSpacing of measurement points = ');
if spacing == 1
    fprintf(fid,'uniform');
else
    fprintf(fid,'logarithmic');
end
fprintf(fid,'\nSPSA iterations (1st MEM step) = %1.0f',I1);
fprintf(fid,'\nMCMC iterations (2nd MEM step) = %1.0f',L);

fprintf(fid,'\n\nPerturbations');
fprintf(fid,'\n-------------');
fprintf(fid,'\n%1.0f  Shc*',pert(1));
fprintf(fid,'\n%1.0f  Grb2',pert(2));
fprintf(fid,'\n%1.0f  Shc*-Grb2',pert(3));
fprintf(fid,'\n%1.0f  Sos',pert(4));
fprintf(fid,'\n%1.0f  Shc*-Grb2-Sos',pert(5));
fprintf(fid,'\n%1.0f  Grb2-Sos',pert(6));
fprintf(fid,'\n%1.0f (EGF-EGFR*)2-GAP',pert(7));
fprintf(fid,'\n%1.0f (EGF-EGFR*)2-GAP-Grb2',pert(8));
fprintf(fid,'\n%1.0f (EGF-EGFR*)2-GAP-Grb2-Sos',pert(9));
fprintf(fid,'\n%1.0f  Ras-GDP',pert(10));
fprintf(fid,'\n%1.0f (EGF-EGFR*)2-GAP-Grb2-Sos-Ras-GDP',pert(11));
fprintf(fid,'\n%1.0f  Ras-GTP*',pert(12));
fprintf(fid,'\n%1.0f (EGF-EGFR*)2-GAP-Grb2-Sos-Ras-GTP',pert(13));

fprintf(fid,'\n\nRate constant values');
fprintf(fid,'\n--------------------');
fprintf(fid,'\nReaction\t\t\tTrue   \t\t\t\tMean Estimated\n');
for m = 1:M
    fprintf(fid,'%+1.0f        \t\t\t%-4.4e\t\t\t%-4.4e\n',m,kappa(2*m-1),kappa_mean(2*m-1));
    fprintf(fid,'%+1.0f        \t\t\t%-4.4e\t\t\t%-4.4e\n',-m,kappa(2*m),kappa_mean(2*m));
end

fprintf(fid,'\nmedAE\n');
fprintf(fid,'-----\n');
fprintf(fid,'%2.4e\t\t',medAE_mean);

fprintf(fid,'\n\nmaxAE\n');
fprintf(fid,'-----\n');
fprintf(fid,'%2.4e\t\t',maxAE_mean);

fprintf(fid,'\n\nDopt\n');
fprintf(fid,'----\n');
fprintf(fid,'%2.4e\t\t',Dopt);

fclose(fid);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Write posterior mode results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

fid = fopen(['../results/' FolderName '/reports/mode.txt'],'w');
fprintf(fid,'POSTERIOR MODE ESTIMATION RESULTS\n');
fprintf(fid,'---------------------------------\n');
fprintf(fid,'Distribution of measurement noise: ');
if noiseType == 1
    fprintf(fid,'i.i.d. Gaussian');
elseif noiseType == 2
    fprintf(fid,'correlated Gaussian');
else
    fprintf(fid,'i.i.d. Uniform');
end
fprintf(fid,'\nStandard deviation of measurement errors = %4.4f',sigma);
fprintf(fid,'\nObservation time = %1.2f (min)',time);
fprintf(fid,'\nNumber of measurement points = %1.0f',Q);
fprintf(fid,'\nSpacing of measurement points = ');
if spacing == 1
    fprintf(fid,'uniform');
else
    fprintf(fid,'logarithmic');
end
fprintf(fid,'\nSPSA iterations (1st MEM step) = %1.0f',I1);
fprintf(fid,'\nMCMC iterations (2nd MEM step) = %1.0f',L);
fprintf(fid,'\nSPSA iterations (3rd MEM step) = %1.0f',I2);

fprintf(fid,'\n\nPerturbations');
fprintf(fid,'\n-------------');
fprintf(fid,'\n%1.0f  Shc*',pert(1));
fprintf(fid,'\n%1.0f  Grb2',pert(2));
fprintf(fid,'\n%1.0f  Shc*-Grb2',pert(3));
fprintf(fid,'\n%1.0f  Sos',pert(4));
fprintf(fid,'\n%1.0f  Shc*-Grb2-Sos',pert(5));
fprintf(fid,'\n%1.0f  Grb2-Sos',pert(6));
fprintf(fid,'\n%1.0f (EGF-EGFR*)2-GAP',pert(7));
fprintf(fid,'\n%1.0f (EGF-EGFR*)2-GAP-Grb2',pert(8));
fprintf(fid,'\n%1.0f (EGF-EGFR*)2-GAP-Grb2-Sos',pert(9));
fprintf(fid,'\n%1.0f  Ras-GDP',pert(10));
fprintf(fid,'\n%1.0f (EGF-EGFR*)2-GAP-Grb2-Sos-Ras-GDP',pert(11));
fprintf(fid,'\n%1.0f  Ras-GTP*',pert(12));
fprintf(fid,'\n%1.0f (EGF-EGFR*)2-GAP-Grb2-Sos-Ras-GTP',pert(13));

fprintf(fid,'\n\nRate constant values');
fprintf(fid,'\n--------------------');
fprintf(fid,'\nReaction\t\tTrue    \t\tMode Estimated\n');
for m = 1:M
    fprintf(fid,'%+1.0f      \t\t%-4.4e\t\t%-4.4e\n',m,kappa(2*m-1),kappa_mode(2*m-1));
    fprintf(fid,'%+1.0f      \t\t%-4.4e\t\t%-4.4e\n',-m,kappa(2*m),kappa_mode(2*m));
end

[logKappaTrue,logkappaFreeTrue] = imposeWcond(log(kappa),W,permMatM);
[logKappaMode,logkappaFreeMode] = imposeWcond(log(kappa_mode),W,permMatM);
reactionNum = ['+1';'+2';'+3';'+5';'+6';'+8';'+9';'+4';'+7';'-1';'-2';'-3';'-5';'-6';'-8';'-9'];
fprintf(fid,'\n\nFree log-rate constant values');
fprintf(fid,'\n-----------------------------');
fprintf(fid,'\nReaction\t\tTrue     \t\tMode Estimated\t\tRMSE\n');
for m = [1,10,2,11,3,12,8,4,13,5,14,9,6,15,7,16]
    fprintf(fid,[reactionNum(m,:) '      \t\t%+4.4e\t\t%+4.4e\t\t\t%8.4e\n'],logkappaFreeTrue(m),logkappaFreeMode(m),rmse(m));
end
       
fprintf(fid,'\nmedAE\n');
fprintf(fid,'-----\n');
fprintf(fid,'%2.4e\t\t',medAE_mode);

fprintf(fid,'\n\nmaxAE\n');
fprintf(fid,'-----\n');
fprintf(fid,'%2.4e\t\t',maxAE_mode);

fprintf(fid,'\n\nDopt\n');
fprintf(fid,'----\n');
fprintf(fid,'%2.4e\t\t',Dopt);

fclose(fid);