% Initial molecular concentrations
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%   Thermodynamically Consistent Bayesian Analysis    %%%%%%%%%%%
%%%%%%%%%%%       of Closed Biochemical Reaction Systems        %%%%%%%%%%%
%%%%%%%%%%%            Posterior Mode Rate Estimation           %%%%%%%%%%%
%%%%%%%%%%%         Authors: Jenkinson, Zhong, Goutsias         %%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 11/04/2010              %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Initial molecular concentrations of reference system (in molecules/cell)
%

c(1)  = 10;        %  Shc*
c(2)  = 11000;     %  Grb2
c(3)  = 10;        %  Shc*-Grb2
c(4)  = 26300;     %  Sos
c(5)  = 10;        %  Shc*-Grb2-Sos
c(6)  = 40000;     %  Grb2-Sos
c(7)  = 1000;      % (EGF-EGFR*)2-GAP
c(8)  = 10;        % (EGF-EGFR*)2-GAP-Grb2
c(9)  = 10;        % (EGF-EGFR*)2-GAP-Grb2-Sos
c(10) = 72000;     %  Ras-GDP
c(11) = 10;        % (EGF-EGFR*)2-GAP-Grb2-Sos-Ras-GDP
c(12) = 10;        %  Ras-GTP*
c(13) = 10;        % (EGF-EGFR*)2-GAP-Grb2-Sos-Ras-GTP

x0 = c;            % set initial molecular concentrations to c

%
% Initial molecular concentrations of perturbed system (in molecules/cell)
% x0p(:,p) is the initial molecular concentration of the pth perturbed system.
%

x0p = repmat(0,[length(c),length(c)]);

for p = 1:length(c)
    x0p(:,p) = c';  % set initial molecular concentrations to c
end

%
% Possible perturbations (only monomers are perturbed)
%

Pi(1)  =  99*c(1);          %  Shc*
Pi(2)  = -0.99*c(2);        %  Grb2
Pi(3)  =  0;                %  Shc*-Grb2
Pi(4)  = -0.99*c(4);        %  Sos
Pi(5)  =  0;                %  Shc*-Grb2-Sos
Pi(6)  =  0;                %  Grb2-Sos
Pi(7)  =  0;                % (EGF-EGFR*)2-GAP
Pi(8)  =  0;                % (EGF-EGFR*)2-GAP-Grb2
Pi(9)  =  0;                % (EGF-EGFR*)2-GAP-Grb2-Sos
Pi(10) =  0;                %  Ras-GDP
Pi(11) =  0;                % (EGF-EGFR*)2-GAP-Grb2-Sos-Ras-GDP
Pi(12) =  0;                %  Ras-GTP*
Pi(13) =  0;                % (EGF-EGFR*)2-GAP-Grb2-Sos-Ras-GTP

for iter = 1:length(c)
    x0p(iter,iter) = c(iter)+Pi(iter);
end