% Hypeparameter calculation
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%   Thermodynamically Consistent Bayesian Analysis    %%%%%%%%%%%
%%%%%%%%%%%       of Closed Biochemical Reaction Systems        %%%%%%%%%%%
%%%%%%%%%%%             Hyperparameter Calculation              %%%%%%%%%%%
%%%%%%%%%%%        Authors: Jenkinson, Zhong, Goutsias          %%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 11/04/2010              %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

clear all;
close all;

kmin = -17;     % minimum log kappa value
kmax = -3;      % maximum log kappa value
kavg = -7;      % average log kappa value
eps  = 0.001;   % prior zero tolerance at kmin 

avg  = 0.5;     % average of measurement error variance 
sd   = 0.5;     % dispersion of measurement error variance

ttau = (1:0.001:3); 

for i = 1:size(ttau,2)
    g_1(i) = ttau(i)*log(ttau(i));
    g_2(i) = kmin-kavg-(1+log(eps))*ttau(i);
    if abs(g_1(i)-g_2(i)) < 1e-3
        inter = i;
    end
end

tau = ttau(inter);

set(0,'DefaultAxesLineWidth',2,'DefaultAxesFontSize',14,...
      'DefaultAxesFontWeight','normal');
lnw = 2;

figure
plot(ttau,g_1,'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(ttau,g_2,'Color',[1 0 0],'Linewidth',lnw)
   axis([1.1*min(ttau) max(ttau) 0 1.2*max(g_1)])
   xlabel('\tau');
   title('{\bf intersection point = \tau value}');
   
r = erfcinv(2*tau*eps*exp(-(kmax-kavg-tau)/tau));

lminus = 0.5*sqrt(2)*r*tau-0.5*sqrt(2*(r^2+2)*tau^2-4*tau*(kmax-kavg));
lplus  = 0.5*sqrt(2)*r*tau+0.5*sqrt(2*(r^2+2)*tau^2-4*tau*(kmax-kavg));

kappa0 = kavg + tau;

epsminus = eps*exp(lminus^2/2);
epsplus  = eps*exp(lplus^2/2);

a = 2 + (avg/sd)^2;
b = avg*(a-1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Hyperparameters of rate constant prior
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

kappa0
tau
lminus
epsminus
lplus
epsplus

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Hyperparameters of error variance
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

a
b