#include <stdio.h>
#include <iostream>
#include <fstream>
#include "nr3matlab.h"
#include "ludcmp.h"
#include "stepper.h"
#include "odeint.h"
#include "steppersie.h"
#include "EGFeqns.h"

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]){
	/* Stiff ODE Chemical Kinetics Integrator
     *
     * Authors: W. Garrett Jenkinson & John Goutsias
	 * 
     * Last Modified: October 22, 2009
     *
     * usage:
	 * [t,x]=odeEGF(kappa,x0,tolTemp,timings);
     */
	
	//set constants of integration
	const Int nvar=13;
	const Doub h1=.01, hmin=0.0;
	 
	//Initialize matlab input output vars
	VecDoub kappa(prhs[0]);
	VecDoub xstart(prhs[1]);
	VecDoub tolerance(prhs[2]);
    VecDoub timings(prhs[3]);
	VecDoub t((timings[2]+1),plhs[0]);
	MatDoub x(nvar,(timings[2]+1),plhs[1]);
	
	//initialize ODE parameters
	Doub k1,k2,k3,k4,k5,k6,k7,k8,k9,k10,k11,k12,k13,k14,k15,k16,k17,k18; 
	
	k1=kappa[0];
	k2=kappa[1];
	k3=kappa[2];
	k4=kappa[3];
	k5=kappa[4];
	k6=kappa[5];
	k7=kappa[6];
	k8=kappa[7];
    k9=kappa[8];
	k10=kappa[9];
	k11=kappa[10];
	k12=kappa[11];
	k13=kappa[12];
	k14=kappa[13];
    k15=kappa[14];
	k16=kappa[15];
	k17=kappa[16];
	k18=kappa[17];
    Doub tstart, tstop;
	tstart = timings[0];
	tstop  = timings[1];
    
    // this makes sure the input variables are not modified in matlab
    VecDoub xstartTemp = xstart;
    
    //initialize the integrator output
    Output out(timings[2]);
    
    // initialize rhs of ODE system
	rhs d(k1,k2,k3,k4,k5,k6,k7,k8,k9,k10,k11,k12,k13,k14,k15,k16,k17,k18);
    
    // create ODE integrator object
	Odeint<StepperSie<rhs> > ode(xstartTemp,tstart,tstop,tolerance[0],tolerance[1],h1,hmin,out,d);
	
    // perform integration
    ode.integrate();
    
    // write output to variables in matlab workspace
	for (Int i=0;i<out.count;i++){
		t[i]=out.xsave[i];
		for (Int j=0;j<x.nrows();j++){
            x[j][i]=out.ysave[j][i];
        }
	}
    
}