% Plot of error variance prior density
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%   Thermodynamically Consistent Bayesian Analysis    %%%%%%%%%%%
%%%%%%%%%%%       of Closed Biochemical Reaction Systems        %%%%%%%%%%%
%%%%%%%%%%%            Error variance prior density             %%%%%%%%%%%
%%%%%%%%%%%         Authors: Goutsias, Zhong, Jenkinson         %%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 11/04/2010              %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

clear all;
close all;

var = (0:0.001:2); 
a   = 3;
b   = 1;

coeff = (b^a/gamma(a));

if coeff == 0
    p(1) = 1;
else
    p(1) = 0;
end
for i = 2:size(var,2);
    p(i) = coeff*(1/var(i))^(a+1)*exp(-b/var(i));
end

mean     = b/(a-1)
variance = b^2/((a-1)^2*(a-2))
mode     = b/(a+1)

set(0,'DefaultAxesLineWidth',2,'DefaultAxesFontSize',14,...
      'DefaultAxesFontWeight','normal');
lnw = 2;

figure
plot(var,p,'Color',[1 0 0],'Linewidth',lnw)
   axis([0 max(var) 0 1.2*max(p)])
   xlabel('\sigma^2');
   title('{\bf error variance prior density}');